@@ -215,6 +215,7 @@ class Emptor(object):
             Pkcp = client private key and cert path
             Cacp =  certificate authority or host server certs path
             Debug = generate trace if True
+            Red = allow redirects if True
             
         
         Instance attributes:
@@ -245,6 +246,7 @@ class Emptor(object):
             content = content returned from last request
             trace = http trace of latest request-response
             reaped = reaped content as determined by reaper response content-type
+            red = allow redirects if true
             
         
         prefix and suffix detail
@@ -320,12 +322,13 @@ class Emptor(object):
     Pkcp = '' # client private key and cert path
     Cacp = False # certificate authority or server certs path. Don't verify if False
     Debug = False # create trace on requests
+    Red = True
     
     def __init__(self, scheme='', domain='', port='', prefix='', suffix='',
             headers=None, hrm='', hct='', hscs=None, hats=None,
             creds=None, cookies=None, xmlns=None, mold='', mdp='',
             preloads=None, qkeys=None, pkeys=None, bkeys=None,
-            pkcp='', cacp=False,  debug=False ):
+            pkcp='', cacp=False,  debug=False, red=True ):
         """ Initialize service instance 
             Parameters:
             
@@ -354,6 +357,7 @@ class Emptor(object):
               pkcp = private key and cert path
               cacp = cert auth path
               debug = create trace
+              red = allow redirects
               
         """
         # optional parameters, 
@@ -391,6 +395,7 @@ class Emptor(object):
             xmlns = []
         self.xmlns = list(xmlns) or list(self.Xmlns)
         self.debug = debug or self.Debug
+        self.red = red or self.Red
         
         #other
         self.response = None
@@ -774,7 +779,7 @@ class Emptor(object):
             """        
         try:
             
-            with Redirector() as red: #redirect stdout, stderr to string
+            with Redirector() as redstd: #redirect stdout, stderr to string
                 #print "body:\n%s" %  body
                 response = requests.request(url=url,
                                             method=self.hrm,
@@ -784,13 +789,14 @@ class Emptor(object):
                                             cookies=self.cookies,
                                             verify=self.cacp,
                                             cert=self.pkcp,
-                                            auth=auth, ) 
+                                            auth=auth,
+                                            allow_redirects=self.red) 
                 
                 self.response = response
                 if self.debug:
-                    red.seek(0) #go to head of file
+                    redstd.seek(0) #go to head of file
                     trace = ''
-                    for line in red: #strip out raw string escapes and reformat
+                    for line in redstd: #strip out raw string escapes and reformat
                         if line.startswith('send: '):
                             trace = "%sRequest: \n\n%s" % (trace, 
                                 line.lstrip("send: '").rstrip("'\n").decode('string_escape'))
@@ -861,7 +867,8 @@ class Emptorage(object):
     def _rosterate(self, entry, scheme='', port='', domain='', prefix='',
                    suffix='', preloads=None, headers=None, 
                    hrm='', hct='',hscs=None, hats=None,
-                   creds=None, xmlns=None, mdp='', pkcp='', cacp=False, debug=False):
+                   creds=None, xmlns=None, mdp='', pkcp='', cacp=False,
+                   debug=False,  red=True):
         """ Generate emptor init args for the given entry and init parameters. 
             Parameters
                 scheme = Server URL scheme
@@ -881,6 +888,7 @@ class Emptorage(object):
                 pkcp = private key cert path
                 cacp = certificate authority certs path
                 debug = create and save httplib trace
+                red = allow redirects
                 
             Special processing of parameters to this function
                 The final instance attributes value will be.
@@ -916,6 +924,7 @@ class Emptorage(object):
                 'pkcp' optional
                 'cacp' optional
                 'debug' optional
+                'red' optional
                 
                 
                     
@@ -938,6 +947,7 @@ class Emptorage(object):
         ia['pkcp'] = entry.get('pkcp', '') or pkcp
         ia['cacp'] = entry.get('cacp', False) or cacp
         ia['debug'] = entry.get('debug', False) or debug
+        ia['red'] = entry.get('red', False) or red
         #service specific
         ia['suffix'] = entry.get('suffix', '')
         ia['mold'] = entry.get('mold', '')  
